@@ -21,23 +21,23 @@ import (
 	"time"
 
 	"github.com/google/go-cmp/cmp"
-	"knative.dev/serving/pkg/autoscaler"
 )
 
-const (
-	podName = "pod"
-)
+type reportedStat struct {
+	Concurrency         float64
+	ProxiedConcurrency  float64
+	RequestCount        float64
+	ProxiedRequestCount float64
+}
 
 func TestNoData(t *testing.T) {
 	now := time.Now()
 	s := newTestStats(now)
 
 	got := s.report(now)
-	want := autoscaler.Stat{
-		Time:                      now,
-		PodName:                   podName,
-		AverageConcurrentRequests: 0.0,
-		RequestCount:              0,
+	want := reportedStat{
+		Concurrency:  0.0,
+		RequestCount: 0,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -54,11 +54,9 @@ func TestSingleRequestWholeTime(t *testing.T) {
 
 	got := s.report(now)
 
-	want := autoscaler.Stat{
-		Time:                      now,
-		PodName:                   podName,
-		AverageConcurrentRequests: 1.0,
-		RequestCount:              1,
+	want := reportedStat{
+		Concurrency:  1.0,
+		RequestCount: 1,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -75,11 +73,9 @@ func TestSingleRequestHalfTime(t *testing.T) {
 	now = now.Add(1 * time.Second)
 	got := s.report(now)
 
-	want := autoscaler.Stat{
-		Time:                      now,
-		PodName:                   podName,
-		AverageConcurrentRequests: 0.5,
-		RequestCount:              1,
+	want := reportedStat{
+		Concurrency:  0.5,
+		RequestCount: 1,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -97,11 +93,9 @@ func TestVeryShortLivedRequest(t *testing.T) {
 	now = now.Add(990 * time.Millisecond) // make the second full
 	got := s.report(now)
 
-	want := autoscaler.Stat{
-		Time:                      now,
-		PodName:                   podName,
-		AverageConcurrentRequests: float64(10) / float64(1000),
-		RequestCount:              1,
+	want := reportedStat{
+		Concurrency:  float64(10) / float64(1000),
+		RequestCount: 1,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -126,11 +120,9 @@ func TestMultipleRequestsWholeTime(t *testing.T) {
 
 	got := s.report(now)
 
-	want := autoscaler.Stat{
-		Time:                      now,
-		PodName:                   podName,
-		AverageConcurrentRequests: 1.0,
-		RequestCount:              3,
+	want := reportedStat{
+		Concurrency:  1.0,
+		RequestCount: 3,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -151,11 +143,9 @@ func TestMultipleRequestsInterleaved(t *testing.T) {
 
 	got := s.report(now)
 
-	want := autoscaler.Stat{
-		Time:                      now,
-		PodName:                   podName,
-		AverageConcurrentRequests: 1.5,
-		RequestCount:              2,
+	want := reportedStat{
+		Concurrency:  1.5,
+		RequestCount: 2,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -169,22 +159,18 @@ func TestOneRequestAcrossReportings(t *testing.T) {
 	s.requestStart(now)
 	now = now.Add(1 * time.Second)
 	got1 := s.report(now)
-	want1 := autoscaler.Stat{
-		Time:                      got1.Time,
-		PodName:                   podName,
-		AverageConcurrentRequests: 1.0,
-		RequestCount:              1,
+	want1 := reportedStat{
+		Concurrency:  1.0,
+		RequestCount: 1,
 	}
 
 	now = now.Add(500 * time.Millisecond)
 	s.requestEnd(now)
 	now = now.Add(500 * time.Millisecond)
 	got2 := s.report(now)
-	want2 := autoscaler.Stat{
-		Time:                      now,
-		PodName:                   podName,
-		AverageConcurrentRequests: 0.5,
-		RequestCount:              0,
+	want2 := reportedStat{
+		Concurrency:  0.5,
+		RequestCount: 0,
 	}
 
 	if diff := cmp.Diff(want1, got1); diff != "" {
@@ -201,13 +187,11 @@ func TestOneProxiedRequest(t *testing.T) {
 	s.proxiedStart(now)
 	now = now.Add(1 * time.Second)
 	got := s.report(now)
-	want := autoscaler.Stat{
-		Time:                             now,
-		PodName:                          podName,
-		AverageConcurrentRequests:        1.0,
-		AverageProxiedConcurrentRequests: 1.0,
-		RequestCount:                     1,
-		ProxiedRequestCount:              1,
+	want := reportedStat{
+		Concurrency:         1.0,
+		ProxiedConcurrency:  1.0,
+		RequestCount:        1,
+		ProxiedRequestCount: 1,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -222,13 +206,11 @@ func TestOneEndedProxiedRequest(t *testing.T) {
 	s.proxiedEnd(now)
 	now = now.Add(500 * time.Millisecond)
 	got := s.report(now)
-	want := autoscaler.Stat{
-		Time:                             now,
-		PodName:                          podName,
-		AverageConcurrentRequests:        0.5,
-		AverageProxiedConcurrentRequests: 0.5,
-		RequestCount:                     1,
-		ProxiedRequestCount:              1,
+	want := reportedStat{
+		Concurrency:         0.5,
+		ProxiedConcurrency:  0.5,
+		RequestCount:        1,
+		ProxiedRequestCount: 1,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -244,13 +226,11 @@ func TestTwoRequestsOneProxied(t *testing.T) {
 	s.requestStart(now)
 	now = now.Add(500 * time.Millisecond)
 	got := s.report(now)
-	want := autoscaler.Stat{
-		Time:                             now,
-		PodName:                          podName,
-		AverageConcurrentRequests:        1.0,
-		AverageProxiedConcurrentRequests: 0.5,
-		RequestCount:                     2,
-		ProxiedRequestCount:              1,
+	want := reportedStat{
+		Concurrency:         1.0,
+		ProxiedConcurrency:  0.5,
+		RequestCount:        2,
+		ProxiedRequestCount: 1,
 	}
 	if diff := cmp.Diff(want, got); diff != "" {
 		t.Errorf("Unexpected stat (-want +got): %v", diff)
@@ -259,42 +239,49 @@ func TestTwoRequestsOneProxied(t *testing.T) {
 
 // Test type to hold the bi-directional time channels
 type testStats struct {
-	Stats
+	reqChan      chan ReqEvent
 	reportBiChan chan time.Time
+	statChan     chan reportedStat
 }
 
 func newTestStats(now time.Time) *testStats {
 	reportBiChan := make(chan time.Time)
-	ch := Channels{
-		ReqChan:    make(chan ReqEvent),
-		ReportChan: (<-chan time.Time)(reportBiChan),
-		StatChan:   make(chan autoscaler.Stat),
+	reqChan := make(chan ReqEvent)
+	statChan := make(chan reportedStat)
+	report := func(acr float64, apcr float64, rc float64, prc float64) {
+		statChan <- reportedStat{
+			Concurrency:         acr,
+			ProxiedConcurrency:  apcr,
+			RequestCount:        rc,
+			ProxiedRequestCount: prc,
+		}
 	}
-	s := NewStats(podName, ch, now)
+	NewStats(now, reqChan, (<-chan time.Time)(reportBiChan), report)
 	t := &testStats{
-		Stats:        *s,
+		reqChan:      reqChan,
 		reportBiChan: reportBiChan,
+		statChan:     statChan,
 	}
 	return t
 }
 
 func (s *testStats) requestStart(now time.Time) {
-	s.ch.ReqChan <- ReqEvent{Time: now, EventType: ReqIn}
+	s.reqChan <- ReqEvent{Time: now, EventType: ReqIn}
 }
 
 func (s *testStats) requestEnd(now time.Time) {
-	s.ch.ReqChan <- ReqEvent{Time: now, EventType: ReqOut}
+	s.reqChan <- ReqEvent{Time: now, EventType: ReqOut}
 }
 
 func (s *testStats) proxiedStart(now time.Time) {
-	s.ch.ReqChan <- ReqEvent{Time: now, EventType: ProxiedIn}
+	s.reqChan <- ReqEvent{Time: now, EventType: ProxiedIn}
 }
 
 func (s *testStats) proxiedEnd(now time.Time) {
-	s.ch.ReqChan <- ReqEvent{Time: now, EventType: ProxiedOut}
+	s.reqChan <- ReqEvent{Time: now, EventType: ProxiedOut}
 }
 
-func (s *testStats) report(now time.Time) autoscaler.Stat {
+func (s *testStats) report(now time.Time) reportedStat {
 	s.reportBiChan <- now
-	return <-s.ch.StatChan
+	return <-s.statChan
 }
